Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(173)

Unified Diff: mojo/shell/public/cpp/application_test_base.h

Issue 1675083002: Rename ApplicationDelegate to ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/public/cpp/application_runner.h ('k') | mojo/shell/public/cpp/connection.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/public/cpp/application_test_base.h
diff --git a/mojo/shell/public/cpp/application_test_base.h b/mojo/shell/public/cpp/application_test_base.h
index 1dc35163e77938c37c719476dce6987bb1e85c89..eec60d814a5310bd6397eb395aae6211d038dd59 100644
--- a/mojo/shell/public/cpp/application_test_base.h
+++ b/mojo/shell/public/cpp/application_test_base.h
@@ -9,8 +9,8 @@
#include "mojo/public/cpp/bindings/array.h"
#include "mojo/public/cpp/bindings/string.h"
#include "mojo/public/cpp/system/macros.h"
-#include "mojo/shell/public/cpp/application_delegate.h"
#include "mojo/shell/public/cpp/application_impl.h"
+#include "mojo/shell/public/cpp/shell_client.h"
#include "mojo/shell/public/interfaces/application.mojom.h"
#include "testing/gtest/include/gtest/gtest.h"
@@ -29,15 +29,15 @@ MojoResult RunAllTests(MojoHandle application_request_handle);
// ApplicationTestBase.
class TestHelper {
public:
- explicit TestHelper(ApplicationDelegate* delegate);
+ explicit TestHelper(ShellClient* client);
~TestHelper();
Shell* shell() { return application_impl_.get(); }
std::string shell_url() { return url_; }
private:
- // The application delegate used if GetApplicationDelegate is not overridden.
- ApplicationDelegate default_application_delegate_;
+ // The application delegate used if GetShellClient is not overridden.
+ ShellClient default_shell_client_;
// The application implementation instance, reconstructed for each test.
scoped_ptr<ApplicationImpl> application_impl_;
@@ -61,8 +61,8 @@ class ApplicationTestBase : public testing::Test {
return test_helper_ ? test_helper_->shell_url() : std::string();
}
- // Get the ApplicationDelegate for the application to be tested.
- virtual ApplicationDelegate* GetApplicationDelegate();
+ // Get the ShellClient for the application to be tested.
+ virtual ShellClient* GetShellClient();
// testing::Test:
void SetUp() override;
« no previous file with comments | « mojo/shell/public/cpp/application_runner.h ('k') | mojo/shell/public/cpp/connection.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698